from utils import get_path

def get(nthrd, verb, iscn):
    # common parameters
    cfg = {
        # Options
        'Threads' : nthrd, # number of threads
        'Verb' : verb, # verbosity
        # Model (geometry or mesh)
        'File' : get_path('crm.geo', 'setup'), # Input file containing the model
        'Pars' : {'surfMeshSize': 0.01, 'growthRatio': 1.2, 'multTipTe': 5.5}, # parameters for input file model
        'Dim' : 3, # problem dimension
        'Format' : 'vtk', # save format (vtk or gmsh)
        # Markers
        'Fluid' : 'field', # Name of physical group containing the fluid
        'Farfield' : ['upstream', 'farfield', 'downstream'], # LIST of names of physical groups containing the farfield boundaries (upstream/downstream should be first/last element)
        'Fuselage' : 'fuselage', # Name of physical group containing the fuselage boundaries
        'Symmetry' : 'symmetry',
        'Wings' : ['wing', 'tail'], # LIST of names of physical groups containing the lifting surface body
        'Wakes' : ['wingWake', 'tailWake'], # LIST of names of physical group containing the wake
        'WakeTips' : ['wingWakeTip', 'tailWakeTip'], # LIST of names of physical group containing the edge of the wake
        'WakeExs' : ['wingWakeEx', 'tailWakeEx'], # LIST of names of physical group containing the edge of the wake and the intersection of lifting surface with fuselage (to be excluded from Wake B.C.)
        'Tes' : ['wingTe', 'tailTe'], # LIST of names of physical group containing the trailing edge
        # Freestream
        #'M_inf' : 0.85, # freestream Mach number
        #'AoA' : 1.0, # freestream angle of attack
        #'Q_inf' : 10990.5, # freestream dynamic pressure (at 37000ft)
        # Geometry
        'S_ref' : 191.85, # reference surface area (383.69 m^2)
        'c_ref' : 7.01, # reference chord length
        'x_ref' : 33.67, # reference point for moment computation (x)
        'y_ref' : 11.91, # reference point for moment computation (y)
        'z_ref' : 4.52, # reference point for moment computation (z)
        # Numerical
        'LSolver' : 'PARDISO', # inner solver (PARDISO, MUMPS or GMRES)
        'G_fill' : 3, # fill-in factor for GMRES preconditioner
        'G_tol' : 1e-5, # tolerance for GMRES
        'G_restart' : 50, # restart for GMRES
        'Rel_tol' : 1e-6, # relative tolerance on solver residual
        'Abs_tol' : 1e-8, # absolute tolerance on solver residual
        'Max_it' : 20 # solver maximum number of iterations
    }
    # define freestream
    if iscn == 0:
        cfg['M_inf'] = 0.85 # cruise Mach
        cfg['Q_inf'] = 12091.9 # FL350
    elif iscn == 1:
        cfg['M_inf'] = 0.85 # maneuver Mach
        cfg['Q_inf'] = 23568.3 # FL200
    else:
        raise RuntimeError('dart_setup - Case not defined!\n')
    return cfg
