from utils import get_path
import numpy as np

def get(iscn):
    # Parameters that should be retrieved from the setup
    nTwist = 3
    nRefAxPts = 5
    # Functions
    def twist(val, geo):
        start = nRefAxPts-nTwist
        for i in range(start, nRefAxPts):
            geo.rot_y['wing'].coef[i] = val[i - start]
    """def sweep(val, geo):
        C = geo.extractCoef('wing')
        for i in range(1, nRefAxPts):
            C[i, 0] += val[i - 1]
        geo.restoreCoef(C, 'wing')
    def taper(val, geo):
        s = geo.extractS('wing')
        slope = (val[1] - val[0]) / (s[-1] - s[0])
        for i in range(nRefAxPts):
            geo.scale_x['wing'].coef[i] = slope * (s[i] - s[0]) + val[0]
    def dihedral(val, geo):
        C = geo.extractCoef('wing')
        for i in range(1, nRefAxPts):
            C[i, 2] += val[i - 1]
        geo.restoreCoef(C, 'wing')"""
    # Configuration
    p = {
        # Input file
        'geoFile' : get_path('ffd.xyz', 'setup'),
        # Disciplines
        'disciplines' : ['aero', 'struct'],
        # Design variables
        'refAxis' : {
            'wing' : {
                'xFraction' : 0.25,
                'alignIndex' : 'j'
             }
        },
        'globalDV' : {
            'twist' : {
                'value' : np.array([0] * nTwist),
                'func' : twist
            }
        },
        'localDV' : {
            'shape' : {
                'axis' : 'z'
            }
        }
    }
    # Add constraints only for first scenario (cruise)
    if iscn == 0:
        p0 = {
            # Constraints
            'thckCon1D' : {
                'thckle_con' : {
                    'ptList' : [[25.34, 3.07, 4.47], [31.21, 10.87, 4.60], [45.26, 29.35, 6.70]],
                    'nCon' : 10,
                    'axis' : [0,0,1]
                 },
                'thckte_con' : {
                    'ptList' : [[36.96, 3.07, 3.56], [38.37, 10.87, 4.49], [47.96, 29.35, 6.87]],
                    'nCon' : 10,
                    'axis' : [0,0,1]
                 },
                 'thcksp_con' : {
                    'ptList' : [[33.38, 3.07, 3.50], [36.06, 10.87, 4.50], [47.00, 29.35, 6.77]],
                    'nCon' : 10,
                    'axis' : [0,0,1]
                 }
            },
            'volCon' : {
                'vr' : {
                    'leList' : [[26.71, 3.14, 4.30], [32.05, 10.87, 4.50], [41.92, 24.37, 5.80]],
                    'teList' : [[33.38, 3.14, 3.50], [36.06, 10.87, 4.50], [43.42, 23.25, 5.80]],
                    'nSpan' : 20,
                    'nChord' : 20
                 }
             },
            'leteCon' : {
                'le_con' : {
                    'volID' : 0,
                    'faceID' : 'iLow'
                },
                'te_con' : {
                    'volID' : 0,
                    'faceID' : 'iHigh'
                }
             }
        }
        p.update(p0)
    return p

