from utils import get_path
from tacs import elements, constitutive, functions
from mphys import MPhysVariables
import numpy as np

def get():
    # define problem
    def problem_setup(scenario_name, fea_assembler, problem):
        # Mass
        if scenario_name == 'cruise':
            problem.addFunction('mass', functions.StructuralMass)
        # Von-Mises failure criterion
        problem.addFunction('ks_fail', functions.KSFailure, ksWeight=100.0, safetyFactor=1.5)
        # Inertial relief gravity load
        if scenario_name == 'cruise':
            g = 1.0 * np.array([0.0, 0.0, -9.81]) # 1.0g (m/s^2)
        elif scenario_name == 'maneuver':
            g = 2.5 * np.array([0.0, 0.0, -9.81]) # 2.5g (m/s^2)
        else:
            raise RuntimeError(f'tacs_setup - undefined scenario: "{scenario_name}"!\n')
        problem.addInertialLoad(g)
        # Engine loads
        We = g * 78.0e3 / 12.0 # N per node
        problem.addLoadToNodes([125, 38, 73, 96, 35, 110, 75, 40, 124, 277, 39, 212], np.append(We, [0., 0., 0.]), nastranOrdering=True)

    return {
        #'element_callback': element_callback,
        'problem_setup': problem_setup,
        'coupling_loads': [MPhysVariables.Structures.Loads.AERODYNAMIC],
        'mesh_file': get_path('crm.bdf', 'setup')
        }
