from utils import get_path

def get(nthrd, verb):
    cfg = {
        # Options
        'Threads' : nthrd, # number of threads
        'Verb' : verb, # verbosity
        # Model (geometry or mesh)
        'File' : get_path('oneraM6.geo', 'setup'), # Input file containing the model
        'Pars' : {'lgt' : 3, 'wdt' : 3, 'hgt' : 3,
                  'msLeRt' : 0.0050, 'msTeRt' : 0.010, 'msLeTp' : 0.0025, 'msTeTp' : 0.010, 'msF' : 0.5}, # parameters for input file model
        'Dim' : 3, # problem dimension
        'Format' : 'vtk', # save format (vtk or gmsh)
        # Markers
        'Fluid' : 'field', # name of physical group containing the fluid
        'Farfield' : ['upstream', 'farfield', 'downstream'], # LIST of names of physical groups containing the farfield boundaries (upstream/downstream should be first/last element)
        'Symmetry' : 'symmetry', # name of physical group containing the symmetry boundaries
        'Wings' : ['wing'], # LIST of names of physical groups containing the lifting surface boundary
        'Wakes' : ['wake'], # LIST of names of physical group containing the wake
        'WakeTips' : ['wakeTip'], # LIST of names of physical group containing the edge of the wake
        'Tes' : ['te'], # LIST of names of physical group containing the trailing edge
        # Freestream
        'M_inf' : 0.839, # freestream Mach number
        'AoA' : 3.06, # freestream angle of attack
        # Geometry
        'S_ref' : .75, # reference surface length
        'c_ref' : .64, # reference chord length
        'x_ref' : 0.0, # reference point for moment computation (x)
        'y_ref' : 0.0, # reference point for moment computation (y)
        'z_ref' : 0.0, # reference point for moment computation (z)
        # Numerical
        'LSolver' : 'PARDISO', # inner solver (PARDISO, MUMPS or GMRES)
        'G_fill' : 2, # fill-in factor for GMRES preconditioner
        'G_tol' : 1e-5, # tolerance for GMRES
        'G_restart' : 50, # restart for GMRES
        'Rel_tol' : 1e-6, # relative tolerance on solver residual
        'Abs_tol' : 1e-8, # absolute tolerance on solver residual
        'Max_it' : 15 # solver maximum number of iterations
    }
    return cfg

