from utils import get_path
import numpy as np

def get():
    # Parameters that should be retrieved from the setup
    nTwist = 4
    nRefAxPts = 5
    # Functions
    def twist(val, geo):
        start = nRefAxPts-nTwist
        for i in range(start, nRefAxPts):
            geo.rot_y['wing'].coef[i] = val[i - start]
    # Configuration
    p = {
        # Input file
        'geoFile' : get_path('ffd.xyz', 'setup'),
        # Disciplines
        'disciplines' : ['aero'],
        # Design variables
        'refAxis' : {
            'wing' : {
                'xFraction' : 0.25,
                'alignIndex' : 'j'
             }
        },
        'globalDV' : {
            'twist' : {
                'value' : np.array([0] * nTwist),
                'func' : twist
            }
        },
        'localDV' : {
            'shape' : {
                'axis' : 'z'
            }
        },
        # Constraints
        'thckCon1D' : {
            'thckle_con' : {
                'ptList' : [[0.121, 0.0, 0.0], [0.758, 1.196, 0.0]],
                'nCon' : 10,
                'axis' : [0,0,1]
             },
            'thckte_con' : {
                'ptList' : [[0.798, 0.0, 0.0], [1.137, 1.196, 0.0]],
                'nCon' : 10,
                'axis' : [0,0,1]
             }
        },
        'volCon' : {
            'vol_con' : {
                'leList' : [[0.01, 0.01, 0.0], [0.70, 1.18, 0.0]],
                'teList' : [[0.79, 0.01, 0.0], [1.13, 1.18, 0.0]],
                'nSpan' : 10,
                'nChord' : 10
             }
         },
        'leteCon' : {
            'le_con' : {
                'volID' : 0,
                'faceID' : 'iLow'
            },
            'te_con' : {
                'volID' : 0,
                'faceID' : 'iHigh'
            }
         }
    }
    return p

