from utils import parse_args
from setup import pygeo_setup
from setup import tacs_setup
from setup import sdpm_setup
from setup import rbfi_setup
from setup import pypk_setup

from omflut import FlutterGroup
from geometry import PyGeoBuilderOMF
from omflut.tacs_structure import TacsBuilder
from omflut import RbfXferBuilder
from sdpm.api.om import SdpmBuilder
from pypk.api_om import PypkBuilder
import openmdao.api as om

class Dynamic(om.Group):
    def setup(self):
        args = parse_args()
        for i in range(2):
            # Builders
            geom = PyGeoBuilderOMF(pygeo_setup.get(-1))
            tacs = TacsBuilder(**tacs_setup.get('modal'))
            sdpm = SdpmBuilder(sdpm_setup.get(args.v, i))
            rbfi = RbfXferBuilder(tacs, sdpm, rbfi_setup.get())
            pypk = PypkBuilder(pypk_setup.get(i))
            # Flutter component
            self.add_subsystem(f'flutter_{i}', FlutterGroup(struct=tacs, xfer=rbfi, aero=sdpm, flutter=pypk, geo=geom))

    def configure(self):
        # Set surface meshes
        for ssys in self.system_iter(recurse=False):
            ssys.geometry.addDisciplinePoints('aero', ssys.mesh_aero.get_val('x_aero0'))
            ssys.geometry.addDisciplinePoints('struct', ssys.mesh_struct.get_val('x_struct0'))
