from utils import get_path
import numpy as np

def get(iscn):
    # Parameters that should be retrieved from the setup
    nTwist = 3
    nRefAxPts = 5
    # Functions
    def twist(val, geo):
        start = nRefAxPts-nTwist
        for i in range(start, nRefAxPts):
            geo.rot_y['wing'].coef[i] = val[i - start]
    # Configuration
    p = {
        # Input file
        'geoFile' : get_path('ffd.xyz', 'setup'),
        # Disciplines
        'disciplines' : ['aero', 'struct'],
        # Design variables
        'refAxis' : {
            'wing' : {
                'xFraction' : 0.25,
                'alignIndex' : 'j'
             }
        },
        'globalDV' : {
            'twist' : {
                'value' : np.array([0] * nTwist),
                'func' : twist
            }
        },
        'localDV' : {
            'shape' : {
                'axis' : 'z'
            }
        }
    }
    # Add constraints only for first scenario (cruise)
    if iscn == 0:
        p0 = {
            # Constraints
            'leRadiusCon' : {
                'lerad_con' : {
                    'leList' : [[0.001, 0.0, 0.0], [7.501, 14.0, 0.0]],
                    'nSpan' : 10,
                    'axis' : [0,0,1],
                    'chordDir' : [1,0,0]
                 }
            },
            'thckCon1D' : {
                #'thckle_con' : {
                #    'ptList' : [[0.02, 0.0, 0.0], [7.52, 14.0, 0.0]],
                #    'nCon' : 10,
                #    'axis' : [0,0,1]
                # },
                'thckte_con' : {
                    'ptList' : [[4.98, 0.0, 0.0], [8.98, 14.0, 0.0]],
                    'nCon' : 10,
                    'axis' : [0,0,1]
                 },
                 'thcksp_con' : {
                    'ptList' : [[3.81, 0.0, 0.0], [3.81, 1.50, 0.0], [8.48, 14.0, 0.0]],
                    'nCon' : 10,
                    'axis' : [0,0,1]
                 }
            },
            'volCon' : {
                'vr' : {
                    #'leList' : [[1.49, 0.01, 0.0], [1.49, 1.50, 0.0], [5.98, 10.50, 0.0]],
                    'leList' : [[1.49, 0.01, 0.0], [1.49, 1.50, 0.0], [7.72, 13.99, 0.0]],
                    #'teList' : [[3.81, 0.01, 0.0], [3.81, 1.50, 0.0], [7.18, 10.50, 0.0]],
                    'teList' : [[3.81, 0.01, 0.0], [3.81, 1.50, 0.0], [8.48, 13.99, 0.0]],
                    'nSpan' : 10,
                    'nChord' : 10
                 }
             },
            'leteCon' : {
                'le_con' : {
                    'volID' : 0,
                    'faceID' : 'iLow'
                },
                'te_con' : {
                    'volID' : 0,
                    'faceID' : 'iHigh'
                }
             }
        }
        p.update(p0)
    return p
