from utils import get_path
import numpy as np

def get(verb, iscn):
    wnc = 40
    cfg = {
        # Verbosity
        'Verb_lvl': verb,
        # Model (geometry or mesh)
        'File': get_path('rae_surf.geo', 'setup'), # input Gmsh file
        'Pars': {'nC': wnc, 'nS': 20, 'pC': 1.15, 'pS': 1.0}, # parameters for Gmsh file (optional)
        # Markers
        'Wing': 'wing', # name of the marker defining the lifting body (wing)
        'Te': 'te', # name of the marker defining the trailing edge of the lifting body
        # Freestream
        #'Mach': 0.0, # Mach number (optional)
        'AoA': 0.0, # angle of attack (optional)
        'AoS': 0.0, # angle of side slip (optional)
        # Unsteady motion
        'Num_wake_div': wnc, # number of cells per chord length in the wake
        'Frequencies': list(np.linspace(0.01, 1.0, 20, endpoint=True)), # list of reduced frequencies
        'Num_modes': 4, # number of modes
        # Geometry
        'Symmetry': True, # whether only half (symmetric) model is provided
        's_ref': 45.5, # reference surface area
        'c_ref': 3.56, # reference chord length
        'x_ref': 0.0, # reference point for moment computation (x)
        'y_ref': 0.0, # reference point for moment computation (y)
        'z_ref': 0.0 # reference point for moment computation (z)
    }
    if iscn == 0:
        cfg['Mach'] = 0.5
    elif iscn == 1:
        cfg['Mach'] = 0.95
    else:
        raise RuntimeError('pypk_setup - Case not defined!\n')
    return cfg
