from utils import get_path

def get(nthrd, verb, iscn):
    # common parameters
    cfg = {
        # Options
        'Threads' : nthrd, # number of threads
        'Verb' : verb, # verbosity
        # Model (geometry or mesh)
        'File' : get_path('rae.geo', 'setup'), # Input file containing the model
        'Pars' : {'mesh_size' : 0.01, 'growth_ratio' : 1.2, 'te_tip_multiplier': 5.0,
                  'algo_2d': 6, 'algo_3d': 10}, # parameters for input file model
        'Dim' : 3, # problem dimension
        'Format' : 'vtk', # save format (vtk or gmsh)
        # Markers
        'Fluid' : 'field', # name of physical group containing the fluid
        'Farfield' : ['upstream', 'farfield', 'downstream'], # LIST of names of physical groups containing the farfield boundaries (upstream/downstream should be first/last element)
        'Symmetry' : 'symmetry', # name of physical group containing the symmetry boundaries
        'Wings' : ['wing'], # LIST of names of physical groups containing the lifting surface boundary
        'Wakes' : ['wake'], # LIST of names of physical group containing the wake
        'WakeTips' : ['wakeTip'], # LIST of names of physical group containing the edge of the wake
        'Tes' : ['te'], # LIST of names of physical group containing the edge of the wake and the trailing edge
        # Freestream
        #'M_inf' : 0.82, # freestream Mach number
        #'AoA' : 2.4, # freestream angle of attack
        #'Q_inf' : 11250., # freestream dynamic pressure (at 35000ft)
        # Geometry
        'S_ref' : 45.5, # reference surface length
        'c_ref' : 3.56, # reference chord length
        'x_ref' : 0.0, # reference point for moment computation (x)
        'y_ref' : 0.0, # reference point for moment computation (y)
        'z_ref' : 0.0, # reference point for moment computation (z)
        # Numerical
        'LSolver' : 'PARDISO', # inner solver (PARDISO, MUMPS or GMRES)
        'G_fill' : 2, # fill-in factor for GMRES preconditioner
        'G_tol' : 1e-5, # tolerance for GMRES
        'G_restart' : 50, # restart for GMRES
        'Rel_tol' : 1e-6, # relative tolerance on solver residual
        'Abs_tol' : 1e-8, # absolute tolerance on solver residual
        'Max_it' : 15 # solver maximum number of iterations
    }
    # define freestream
    from setup.init_dv import aoa
    cfg['AoA'] = aoa[iscn] # angle of attack
    if iscn == 0:
        cfg['M_inf'] = 0.82 # cruise Mach
        cfg['Q_inf'] = 11250.0 # FL350
    elif iscn == 1:
        cfg['M_inf'] = 0.78 # maneuver Mach
        cfg['Q_inf'] = 19850.0 # FL200
    else:
        raise RuntimeError('dart_setup - Case not defined!\n')
    return cfg
