from utils import parse_args
from setup import pygeo_setup, dart_setup, tacs_setup, meld_setup

from dartflo.dart.api.mphys import DartBuilder
from tacs.mphys import TacsBuilder
from funtofem.mphys.mphys_meld import MeldBuilder
from geometry import PyGeoBuilder
from mphys.scenarios.aerostructural import ScenarioAeroStructural
from mphys import MultipointParallel, MPhysVariables
import openmdao.api as om

class Static(MultipointParallel):
    def setup(self):
        # Create the scenarios
        args = parse_args()
        for i, scn in enumerate(['cruise', 'maneuver']):
            # create the builders
            geom = PyGeoBuilder(pygeo_setup.get(i))
            dart = DartBuilder(dart_setup.get(args.k, args.v, i), scenario='aerostructural', task='optimization', saveAll=False, raiseError=False)
            tacs = TacsBuilder(**tacs_setup.get())
            meld = MeldBuilder(dart, tacs, isym=1, **meld_setup.get())
            # create the scenarios
            csn = self.mphys_add_scenario(scn, ScenarioAeroStructural(aero_builder=dart, struct_builder=tacs, ldxfer_builder=meld, geometry_builder=geom, in_MultipointParallel=True), coupling_nonlinear_solver=om.NonlinearBlockGS(maxiter=10, iprint=2, use_aitken=True, rtol=1e-6, atol=1e-8, aitken_initial_factor=0.75), coupling_linear_solver=om.LinearBlockGS(maxiter=10, iprint=2, use_aitken=True, rtol=1e-6, atol=1e-8, aitken_initial_factor=0.75))

    def configure(self):
        # Configure the multipoint group
        super().configure()
        # Configure the scnenarios
        self.aero_idv = []
        for i, ssys in enumerate(self.system_iter(recurse=False)):
            # set surface meshes
            ssys.geometry.setConstrainedSurface(ssys.aero_mesh.get_triangulated_surface())
            ssys.geometry.addDisciplinePoints('aero', ssys.aero_mesh.get_val(MPhysVariables.Aerodynamics.Surface.Mesh.COORDINATES))
            ssys.geometry.addDisciplinePoints('struct', ssys.struct_mesh.masker.get_val(f'{MPhysVariables.Structures.Mesh.COORDINATES}_masked'))
            # save DV
            if i == 0:
                # geometrical design variables (size)
                sizes = ssys.geometry.getSizes()
                self.geo_ntwist = sizes['twist']
                self.geo_nshape = sizes['shape']
                # structural design variables
                self.struct_idv = ssys.coupling.struct.fea_assembler.getOrigDesignVars()
                self.struct_bdv = ssys.coupling.struct.fea_assembler.getDesignVarRange()
                self.struct_sdv = ssys.coupling.struct.fea_assembler.scaleList
            # aerodynamic design variables
            self.aero_idv.append(ssys.coupling.aero.solver.sol.pbl.alpha * 180 / 3.14159)
