def parse():
    from argparse import ArgumentParser
    parser = ArgumentParser()
    parser.add_argument('folder', help='folder where cases database is')
    parser.add_argument('--scale', help='scale variables', action='store_true')
    parser.add_argument('--write', help='write to disk', action='store_true')
    return parser.parse_args()

def path(folder):
    import os.path
    for dir in ['', 'workspace']:
        fpath = os.path.abspath(os.path.join(folder, dir, 'cases.sql'))
        if os.path.isfile(fpath):
            return fpath
    raise OSError('Could not find "cases.sql" file!\n')

def detect(case):
    v = {'dv' : [], 'cons' : [], 'obj' : [], 'val' : []}
    # DV
    names = ['aoa', 'aoa_cruise', 'aoa_maneuver']
    for name in names:
        try:
            case.get_design_vars()[name][0]
            v['dv'].append(name)
        except:
            pass
    # CON
    names = []
    for scn in ['cruise', 'maneuver', 'static.cruise', 'static.maneuver']:
        names.extend([f'{scn}.cl', f'flight.trim_{scn}.n', f'{scn}.ks_fail'])
    for scn in ['dynamic.flutter_0', 'dynamic.flutter_1']:
        names.extend([f'{scn}.g_agg'])
    names.extend(['flight.volume_match.vc', 'flight.fuel_match.fm'])
    for name in names:
        try:
            case.get_constraints()[name][0]
            v['cons'].append(name)
        except:
            pass
    # OBJ
    names = ['cruise.cd', 'flight.fuel_burn.fb']
    for name in names:
        try:
            case.get_objectives()[name][0]
            v['obj'].append(name)
        except:
            pass
    # VAL (MISC)
    names = []
    for scn in ['static.cruise', 'static.maneuver']:
        names.extend([f'{scn}.cl', f'{scn}.cd', f'{scn}.mass'])
    for scn in ['dynamic.flutter_0', 'dynamic.flutter_1']:
        names.extend([f'{scn}.flutter.f_speed', f'{scn}.flutter.f_mode'])
    for name in names:
        try:
            case.get_val(name)[0]
            v['val'].append(name)
        except:
            pass
    # compute size and return
    s = 1
    h = 'it'
    for key in v.keys():
        for vname in v[key]:
            s += 1
            h += f', {vname}'
    return v, s, h

def main():
    import openmdao.api as om
    import numpy as np
    args = parse()
    cases = om.CaseReader(path(args.folder)).get_cases()
    v, s, h = detect(cases[0])
    mat = np.zeros((len(cases), s))
    for i, case in enumerate(cases):
        mat[i,0] = i
        j = 1
        for vname in v['dv']:
            mat[i,j] = case.get_design_vars(scaled=args.scale)[vname][0]
            j += 1
        for vname in v['cons']:
            mat[i,j] = case.get_constraints(scaled=args.scale)[vname][0]
            j += 1
        for vname in v['obj']:
            mat[i,j] = case.get_objectives(scaled=args.scale)[vname][0]
            j += 1
        for vname in v['val']:
            mat[i,j] = case.get_val(vname)[0]
            j += 1
    # print
    print(h)
    for i in range(len(cases)):
        np.set_printoptions(formatter={'float': '{:0.3f}'.format})
        print(str(mat[i,:]).replace('\n', ''))
    # save
    if args.write:
        np.savetxt('history.dat', mat, header=h)

if __name__ == '__main__':
    main()

