# Load env
. ~/.profile

# Display usage
function usage()
{
    echo "Usage: $0 WDIR -j N -k T : run case WDIR using N MPI processes with T threads each."
    exit 1
}

# Parse
# default
NCORES=1
NTHREADS=1
# mandatory
if [[ "$#" -ge 1 ]]; then
    # set case dir
    WDIR=$1
    shift
    # check path
    if [[ ! -d $WDIR ]]; then
        echo "$WDIR is not a directory!"
        usage
        exit 1
    fi
else
    echo "At least one mandatory parameter (working directory WDIR) is required!"
    usage
    exit 1
fi
# optional
while [ "$1" != "" ];
do
    case $1 in
    -j)  shift
        NCORES=$1 ;;
    -k)  shift
        NTHREADS=$1 ;;
    -h)
        usage ;;
    *)                     
        echo "$0: Unknown option $1!"
        usage ;;
    esac
    shift
done

# Run and redirect output+error in log
echo "Running case $WDIR on ${NCORES}x${NTHREADS} thread(s)."
cd $WDIR
if [ ! -d workspace ]; then
  mkdir workspace
fi
stim="$(date +%s)"
if [ $NCORES = 1 ] ; then
    python3 run.py -k $NTHREADS 2>&1 -v | tee workspace/log
elif [ $NCORES = 2 ] ; then
    mpirun -n $NCORES --map-by node:PE=$NTHREADS --output-filename workspace/logs python3 run.py -k $NTHREADS -v
else
    echo "Running with more than 2 MPI processes is currently not supported!"
    exit 1
fi
etim="$(date +%s)"
echo "Elapsed time: $(($etim-$stim)) seconds on $NCORESx$NTHREADS thread(s)."
